@@ -25,7 +25,7 @@ class ESDTest(unittest.TestCase):
                        't4': tables.Float32Col(pos=13),
                        't_trigger': tables.Float32Col(pos=14)}
         file = MagicMock()
-        result = esd.create_table(file, sentinel.group)
+        result = esd._create_events_table(file, sentinel.group)
         file.create_table.assert_called_once_with(sentinel.group, 'events',
                                                   description,
                                                   createparents=True)
@@ -49,7 +49,7 @@ class ESDTest(unittest.TestCase):
                        'dew_point': tables.Float32Col(pos=14),
                        'wind_chill': tables.Float32Col(pos=15)}
         file = MagicMock()
-        result = esd.create_weather_table(file, sentinel.group)
+        result = esd._create_weather_table(file, sentinel.group)
         file.create_table.assert_called_once_with(sentinel.group, 'weather',
                                                   description,
                                                   createparents=True)
@@ -65,10 +65,10 @@ class ESDTest(unittest.TestCase):
                   [2, 139, 397, 2], [0, 1085, 5212, 0],
                   0.0, 0.3085, 1.5414, 0.0, -999.0, 15.0, 12.5, -999.0, 17.5]]
         table = []
-        timestamp = esd.read_line_and_store_event(comment_input, table)
+        timestamp = esd._read_line_and_store_event(comment_input, table)
         self.assertEqual(timestamp, 0.)
         self.assertEqual(len(table), 0)
-        timestamp = esd.read_line_and_store_event(input, table)
+        timestamp = esd._read_line_and_store_event(input, table)
         self.assertEqual(timestamp, int(input[2]))
         self.assertEqual(len(table), 1)
         self.assertEqual(table[0], output)
@@ -81,10 +81,10 @@ class ESDTest(unittest.TestCase):
         output = [[0, 1390780801, 19.4, 6.8, 35, 83, 986.65, 275, 4, 0, 0,
                    0.66, 0.0, 6, 4.1, 3.7]]
         table = []
-        timestamp = esd.read_line_and_store_weather(comment_input, table)
+        timestamp = esd._read_line_and_store_weather(comment_input, table)
         self.assertEqual(timestamp, 0.)
         self.assertEqual(len(table), 0)
-        timestamp = esd.read_line_and_store_weather(input, table)
+        timestamp = esd._read_line_and_store_weather(input, table)
         self.assertEqual(timestamp, int(input[2]))
         self.assertEqual(len(table), 1)
         self.assertEqual(table[0], output)
